@@ -7,7 +7,8 @@
 # Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 #                                                                              #
-# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
+# This file is part of PyGithub.                                               #
+# http://pygithub.github.io/PyGithub/v1/index.html                             #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -185,6 +186,7 @@ def ReplayingHttpsConnection(testCase, file, *args, **kwds):
 
 class BasicTestCase(unittest.TestCase):
     recordMode = False
+    tokenAuthMode = False
 
     def setUp(self):
         unittest.TestCase.setUp(self)
@@ -263,8 +265,15 @@ class TestCase(BasicTestCase):
         github.Requester.Requester.setDebugFlag(True)
         github.Requester.Requester.setOnCheckMe(self.getFrameChecker())
 
-        self.g = github.Github(self.login, self.password)
+        if self.tokenAuthMode:
+            self.g = github.Github(self.oauth_token)
+        else:
+            self.g = github.Github(self.login, self.password)
 
 
 def activateRecordMode():  # pragma no cover (Function useful only when recording new tests, not used during automated tests)
     BasicTestCase.recordMode = True
+
+
+def activateTokenAuthMode():  # pragma no cover (Function useful only when recording new tests, not used during automated tests)
+    BasicTestCase.tokenAuthMode = True
